===========
**TRIBUS**
===========

@@DESCRIPTIONLINES@@
@@DESCRIPTION@@
@@DESCRIPTIONLINES@@

:Author: @@AUTHOR@@
:Date:   @@DATE@@
:Copyright: GPL-3
:Version: @@VERSION@@
:Manual section: 1
:Manual group: Web
:Tags: ldap, aguilas, user management, ajax, php, mysql
:Support: @@URL@@
:Summary: @@DESCRIPTION@@

**DESCRIPTION**
===============

@@COMMONINTRO@@
